#include <SPI.h>
#include <nRF24L01.h>
#include <RF24.h>

RF24 radio(10, 9); // CE, CSN
int previousInductionState = LOW; 		// Set the initial state
int InductionState = LOW; 				// Set the initial state
int previousDetectedInduction =  LOW; 	// Set the initial state
unsigned long startTime = 0;

void setup() {
  radio.begin();
  radio.openWritingPipe(0x1A2B3C4D); // Receiver address
  radio.setPALevel(RF24_PA_LOW); // Set radio power to LOW
  radio.stopListening();
  pinMode(2, INPUT_PULLUP); // Set pin 2 as input - HIGH when induction is off
}

void loop() {
  int detectedInduction = !digitalRead(2); // Read the current state; HIGH when LOW is detected (induction is on)

 
// This part of the code makes sure that the information about whether the Induction Cooktop is turned off, is sent only when the Induction Cooktop is turned off continuously for at least 5 seconds.
// The lower power levels of the induction usually turn on/off the power every second or two, which we don't want to bother the receiver.
  
  if (previousDetectedInduction == HIGH && detectedInduction == LOW) {
    startTime = millis(); // Reset the timer on every change from HIGH to LOW
    previousDetectedInduction = LOW;
  }

  if (detectedInduction == LOW && (millis() - startTime) >= 5000) 
    InductionState = LOW; // Wait for 5 seconds, and if detectedInduction is still continuously LOW, change the state to LOW

  if (detectedInduction == HIGH) {
    InductionState = HIGH;
    previousDetectedInduction = HIGH;
  }
  

// Sending the status of the Induction Cooktop to the receiver, but only when the state changes.

  if (InductionState != previousInductionState) {
    radio.write(&InductionState, sizeof(InductionState));
    previousInductionState = InductionState; // Update the previous state
  }

  delay(100); // Small delay for reading stability
}
